package Trida;
# balík implementující školní třídu
# obsahuje odkaz na pole odkazů na objekty typu Zak
#
# metody:
#   vloz_zaka(žák)       přidá žáka do třídy (žák je odkaz na objekt typu Zak)
#   hledej_zaka("jméno") vydá odkaz na žáka daného jména nebo undef
#   vyrad_zaka(žák)      vyřadí žáka (dostane odkaz) ze třídy
#   seznam_abecedne()    vypíše žáky ve třídě v abecedním pořadí
#   seznam_prospech()    vypíše žáky ve třídě podle prospěchu
#   nacti("jméno")       načte třídu z diskového souboru
#   uloz("jméno")        uloží třídu do souboru

use locale;
use Moose;
use Zak;

has zaci => ( is => 'rw', isa => 'ArrayRef', default => sub { [] } );

sub vloz_zaka {
    my $self = shift;
    my $zak = shift;
    push( @{$self->zaci}, $zak );
}

sub vyrad_zaka {
    my $self = shift;
    my $zak = shift;
    for ( my $i=0; $i<@{$self->zaci}; $i++ ) {
        if ( $zak == $self->zaci->[$i] ) {
            splice( @{$self->zaci}, $i, 1 );
        }
    }
}

sub hledej_zaka {
    my $self = shift;
    my $jmeno = shift;
    foreach my $zak ( @{$self->zaci} ) {
        if ( $zak->jmeno eq $jmeno ) {
            return $zak;
        }
    }
    return undef;
}

sub seznam_abecedne {
    my $self = shift;
    foreach my $zak ( sort srovnej_jmena @{$self->zaci} ) {
        $zak->vypis();
    }
}

sub srovnej_jmena {
    return ( $a->jmeno cmp $b->jmeno );
}

sub seznam_prospech {
    my $self = shift;
    foreach my $zak ( sort srovnej_prospech @{$self->zaci} ) {
        $zak->vypis();
    }
}

sub srovnej_prospech {
    return ( $a->prospech <=> $b->prospech );
}

sub nacti {
    my $self = shift;
    my $soubor = shift;
    $self->zaci( [] );

    my ( $radek, $zak, $jmeno, $prospech, $DATA );
    if ( open($DATA, $soubor) ) {
        while ( $radek = <$DATA> ) {
            chomp($radek);
            ($jmeno,$prospech) = split( /:/, $radek );
            $zak = Zak->new(jmeno=>$jmeno, prospech=>$prospech);
            $self->vloz_zaka($zak);
        }
        close($DATA);
        return 1;
    } else {
        print STDERR "Nelze otevřít soubor $soubor!\n";
        return 0;
    }
}

sub uloz {
    my $self = shift;
    my $soubor = shift;
    my $DATA;
    if ( open($DATA, ">$soubor") ) {
        foreach my $zak ( @{$self->zaci} ) {
            print $DATA $zak->jmeno, ":", $zak->prospech, "\n";
        }
        close($DATA);
        return 1;
    } else {
        print STDERR "Nemohu zapisovat do souboru $soubor!\n";
        return 0;
    }
}

1;
